@@ -24,8 +24,6 @@ def get_isabellaalstrom(github, selected_repos):
             content = content.decoded_content.decode()
             version = content.split()[0]
 
-            updated_at = repo.updated_at.isoformat().split('T')[0]
-
             remote_location = REUSE.format(org, name, name)
             remote_location = remote_location + '.js'
 
@@ -34,7 +32,6 @@ def get_isabellaalstrom(github, selected_repos):
             changelog = visit_repo
 
             data[name] = {}
-            data[name]['updated_at'] = updated_at
             data[name]['version'] = version
             data[name]['remote_location'] = remote_location
             data[name]['visit_repo'] = visit_repo
