@@ -22,8 +22,6 @@ def get_data(github, selected_repos):
 
             release = list(repo.get_releases())[0]
 
-            updated_at = repo.updated_at.isoformat().split('T')[0]
-
             version = release.tag_name
 
             remote_location = REUSE.format(org, name, name)
@@ -34,7 +32,6 @@ def get_data(github, selected_repos):
             changelog = release.html_url
 
             data[name] = {}
-            data[name]['updated_at'] = updated_at
             data[name]['version'] = version
             data[name]['remote_location'] = remote_location
             data[name]['visit_repo'] = visit_repo
