@@ -21,8 +21,6 @@ def get_data(github, selected_repos):
                 fullname = repo.name
                 print("Generating json for:", "{}/{}".format(org, name))
 
-                updated_at = repo.updated_at.isoformat().split('T')[0]
-
                 version = list(repo.get_commits())[0].sha[0:6]
 
                 remote_location = REUSE.format(org, fullname, name)
@@ -33,7 +31,6 @@ def get_data(github, selected_repos):
                 changelog = VISIT.format(org, fullname)
 
                 data[name] = {}
-                data[name]['updated_at'] = updated_at
                 data[name]['version'] = version
                 data[name]['remote_location'] = remote_location
                 data[name]['visit_repo'] = visit_repo
